@@ -66,8 +66,8 @@ void EventView::setGlobalCollectionSelection(CalendarSupport::CollectionSelectio
 }
 
 EventView::EventView(QWidget *parent)
-    : QWidget(parent),
-      d_ptr(new EventViewPrivate())
+    : QWidget(parent)
+    , d_ptr(new EventViewPrivate())
 {
     QByteArray cname = metaObject()->className();
     cname.replace(':', '_');
@@ -115,7 +115,7 @@ void EventView::setHolidayRegion(const KHolidays::HolidayRegionPtr &holidayRegio
 
 int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
 {
-    KDateTime dateTime(date, preferences()->timeSpec());
+    QDateTime dateTime(date, {}, Qt::LocalTime);
 
     int availableOccurrences = KCalUtils::RecurrenceActions::availableOccurrences(inc, dateTime);
 
@@ -131,7 +131,7 @@ int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
     case KCalUtils::RecurrenceActions::SelectedOccurrence:
         return KCalUtils::RecurrenceActions::SelectedOccurrence;
 
-    case KCalUtils::RecurrenceActions::AllOccurrences: {
+    case KCalUtils::RecurrenceActions::AllOccurrences:
         Q_ASSERT(availableOccurrences & KCalUtils::RecurrenceActions::SelectedOccurrence);
 
         // if there are all kinds of ooccurrences (i.e. past present and future) the user might
@@ -142,9 +142,8 @@ int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
                                          "Should the changes be applied only to this single occurrence, "
                                          "also to future items, or to all items in the recurrence?");
             return KCalUtils::RecurrenceActions::questionSelectedFutureAllCancel(
-                       message, caption, itemSelected, itemFuture, itemAll, this);
+                message, caption, itemSelected, itemFuture, itemAll, this);
         }
-    }
 
     default:
         Q_ASSERT(availableOccurrences & KCalUtils::RecurrenceActions::SelectedOccurrence);
@@ -153,7 +152,7 @@ int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
                                      "Should the changes be applied only to this single occurrence "
                                      "or to all items in the recurrence?");
         return KCalUtils::RecurrenceActions::questionSelectedAllCancel(
-                   message, caption, itemSelected, itemAll, this);
+            message, caption, itemSelected, itemAll, this);
         break;
     }
 
@@ -280,7 +279,7 @@ bool EventView::hasConfigurationDialog() const
     return false;
 }
 
-void EventView::setDateRange(const KDateTime &start, const KDateTime &end,
+void EventView::setDateRange(const QDateTime &start, const QDateTime &end,
                              const QDate &preferredMonth)
 {
     Q_D(EventView);
@@ -288,30 +287,30 @@ void EventView::setDateRange(const KDateTime &start, const KDateTime &end,
     d->startDateTime = start;
     d->endDateTime = end;
     showDates(start.date(), end.date(), preferredMonth);
-    const QPair<KDateTime, KDateTime> adjusted = actualDateRange(start, end, preferredMonth);
+    const QPair<QDateTime, QDateTime> adjusted = actualDateRange(start, end, preferredMonth);
     d->actualStartDateTime = adjusted.first;
     d->actualEndDateTime = adjusted.second;
 }
 
-KDateTime EventView::startDateTime() const
+QDateTime EventView::startDateTime() const
 {
     Q_D(const EventView);
     return d->startDateTime;
 }
 
-KDateTime EventView::endDateTime() const
+QDateTime EventView::endDateTime() const
 {
     Q_D(const EventView);
     return d->endDateTime;
 }
 
-KDateTime EventView::actualStartDateTime() const
+QDateTime EventView::actualStartDateTime() const
 {
     Q_D(const EventView);
     return d->actualStartDateTime;
 }
 
-KDateTime EventView::actualEndDateTime() const
+QDateTime EventView::actualEndDateTime() const
 {
     Q_D(const EventView);
     return d->actualEndDateTime;
@@ -462,9 +461,8 @@ void EventView::doSaveConfig(KConfigGroup &)
 {
 }
 
-QPair<KDateTime, KDateTime> EventView::actualDateRange(const KDateTime &start,
-        const KDateTime &end,
-        const QDate &preferredMonth) const
+QPair<QDateTime, QDateTime> EventView::actualDateRange(const QDateTime &start, const QDateTime &end,
+                                                       const QDate &preferredMonth) const
 {
     Q_UNUSED(preferredMonth);
     return qMakePair(start, end);
@@ -515,7 +513,11 @@ void EventView::setChanges(Changes changes)
 {
     Q_D(EventView);
     if (d->mChanges == NothingChanged) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+        QMetaObject::invokeMethod(this, &EventView::updateView, Qt::QueuedConnection);
+#else
         QMetaObject::invokeMethod(this, "updateView", Qt::QueuedConnection);
+#endif
     }
 
     d->mChanges = changes;
@@ -536,7 +538,6 @@ void EventView::restoreConfig(const KConfigGroup &configGroup)
         d->collectionSelectionModel = nullptr;
         d->setUpModels();
     } else if (useCustom) {
-
         if (!d->collectionSelectionModel) {
             // Sort the calendar model on calendar name
             QSortFilterProxyModel *sortProxy = new QSortFilterProxyModel(this);
@@ -549,7 +550,8 @@ void EventView::restoreConfig(const KConfigGroup &configGroup)
 
             // Only show the first column.
             KRearrangeColumnsProxyModel *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
-            columnFilterProxy->setSourceColumns(QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
+            columnFilterProxy->setSourceColumns(
+                QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
             columnFilterProxy->setSourceModel(sortProxy);
 
             // Make the calendar model checkable.
@@ -558,8 +560,8 @@ void EventView::restoreConfig(const KConfigGroup &configGroup)
 
             d->setUpModels();
         }
-        const KConfigGroup selectionGroup =
-            configGroup.config()->group(configGroup.name() + QLatin1String("_selectionSetup"));
+        const KConfigGroup selectionGroup
+            = configGroup.config()->group(configGroup.name() + QLatin1String("_selectionSetup"));
 
         KViewStateMaintainer<ETMViewStateSaver> maintainer(selectionGroup);
         maintainer.setSelectionModel(d->collectionSelectionModel->selectionModel());
@@ -575,8 +577,8 @@ void EventView::saveConfig(KConfigGroup &configGroup)
     configGroup.writeEntry("UseCustomCollectionSelection", d->collectionSelectionModel != nullptr);
 
     if (d->collectionSelectionModel) {
-        KConfigGroup selectionGroup =
-            configGroup.config()->group(configGroup.name() + QLatin1String("_selectionSetup"));
+        KConfigGroup selectionGroup
+            = configGroup.config()->group(configGroup.name() + QLatin1String("_selectionSetup"));
 
         KViewStateMaintainer<ETMViewStateSaver> maintainer(selectionGroup);
         maintainer.setSelectionModel(d->collectionSelectionModel->selectionModel());
@@ -640,7 +642,7 @@ QColor EventView::itemFrameColor(const QColor &color, bool selected)
     if (color.isValid()) {
         return selected ? QColor(85 + color.red() * 2.0 / 3,
                                  85 + color.green() * 2.0 / 3,
-                                 85 + color.blue() * 2.0 / 3) : color.dark(115);
+                                 85 + color.blue() * 2.0 / 3) : color.darker(115);
     } else {
         return Qt::black;
     }
@@ -650,8 +652,8 @@ QString EventView::iconForItem(const Akonadi::Item &item)
 {
     QString iconName;
     Akonadi::Collection collection = item.parentCollection();
-    while (collection.parentCollection().isValid() &&
-            collection.parentCollection() != Akonadi::Collection::root()) {
+    while (collection.parentCollection().isValid()
+           && collection.parentCollection() != Akonadi::Collection::root()) {
         collection = calendar()->collection(collection.parentCollection().id());
     }
 
@@ -671,4 +673,3 @@ void EventView::onCollectionChanged(const Akonadi::Collection &collection,
         updateView();
     }
 }
-
